/*
 *  pamac-vala
 *
 *  Copyright 2016 Raphaël Rochet
 *  Copyright (C) 2018 Guillaume Benoit <guillaume@manjaro.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a get of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

.pamac-updates-list {
	margin: 10px;
	padding-left: 20px;
}

.pamac-updates-menubutton {
	/* Meant to be used as an override to display a small system-menu-action */
	border-radius: 10px;
	padding: 0px 4px;
}
.pamac-updates-menubutton:hover, .pamac-updates-menubutton:focus {
	/* 1px borders disapears, need to compensate */
	padding: 1px 5px;
}
.pamac-updates-menubutton > StIcon {
	icon-size: 16px;
}
